netapp_ontap.models.aggregate_spare API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_spare`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateSpareSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateSpare object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `checksum_style: str GET`

    The checksum type that has been assigned to the spares.

    Valid choices:

    - block
    - advanced_zoned
  `disk_class: str GET`

    Disk class of spares.

    Valid choices:

    - unknown
    - capacity
    - performance
    - archive
    - solid_state
    - array
    - virtual
    - data_center
    - capacity_flash
  `disk_type: str GET`

    Type of disk.

    Valid choices:

    - fc
    - lun
    - nl_sas
    - nvme_ssd
    - sas
    - sata
    - scsi
    - ssd
    - ssd_cap
    - ssd_zns
    - vmdisk
  `is_partition: bool GET`

    Indicates whether a disk is partitioned (true) or whole (false)

    Example: true

  `layout_requirements: List[LayoutRequirement] GET`

    Available RAID protections and their restrictions.

  `node: Node GET`

    The node field of the aggregate_spare.

  `size: Size GET`

    Usable size of each spare, in bytes.

    Example: 10156769280

  `syncmirror_pool: str GET`

    SyncMirror spare pool.

    Valid choices:

    - pool0
    - pool1
  `total: Size GET`

    Total number of spares in the bucket. The total spare count for each class of spares also includes reserved spare capacity recommended by ONTAP best practices.

    Example: 10

  `usable: Size GET`

    Total number of usable spares in the bucket. The usable count for each class of spares does not include reserved spare capacity recommended by ONTAP best practices.

    Example: 9